@@ -1,3 +1,11 @@
+{-# LANGUAGE CPP #-}
+
+-- if MIN_VERSION_Cabal is not defined, then most likely we have old
+-- GHC or/and old cabal-install in use.
+#ifndef MIN_VERSION_Cabal
+#define MIN_VERSION_Cabal(x,y,z) 0
+#endif
+
 import Distribution.Simple
 import Distribution.Simple.Setup
 import Distribution.PackageDescription
@@ -26,7 +34,11 @@ main = defaultMainWithHooks simpleUserHooks {
   where
     defaultPostConf :: Args -> ConfigFlags -> PackageDescription -> LocalBuildInfo -> IO ()
     defaultPostConf args flags pkgdescr lbi = do
+#if MIN_VERSION_Cabal(2,3,0)
+      libdir_ <- getDbProgramOutput (fromFlag (configVerbosity flags))
+#else
       libdir_ <- rawSystemProgramStdoutConf (fromFlag (configVerbosity flags))
+#endif
                      ghcProgram (withPrograms lbi) ["--print-libdir"]
       let libdir = reverse $ dropWhile isSpace $ reverse libdir_
 
